aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-ppi.c
diff options
context:
space:
mode:
authorgerald <gerald@f5534014-38df-0310-8fa8-9805f1628bb7>2011-06-20 20:51:42 +0000
committergerald <gerald@f5534014-38df-0310-8fa8-9805f1628bb7>2011-06-20 20:51:42 +0000
commit64c55fd4dde8d3a00ceaf1c7a28a8627e35bf8a0 (patch)
treee25b336edc337647c96c96f77049b51289dc1c25 /epan/dissectors/packet-ppi.c
parent3272a610d46300e3563cb22191dc071c14be40e6 (diff)
From Jon Ellch via bug 5175:
Please see the attached patch which updates the ppi-geolocation support to v2.0 of the specification. This iteration adds a new tag (sensor) and removes support for velocity/acceleration from the vector tag. Most of the changes center on the Vector tag. Everything that takes place elsewhere is cosmetic. I ran this iteration through fuzz-test and check-APIs just like last time. From me: Replace tvb_get_ephemeral_string with tvb_format_text. Move dissector registration to the bottom of each file. git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@37733 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'epan/dissectors/packet-ppi.c')
-rw-r--r--epan/dissectors/packet-ppi.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/epan/dissectors/packet-ppi.c b/epan/dissectors/packet-ppi.c
index 6da3feb88f..b10e1a7232 100644
--- a/epan/dissectors/packet-ppi.c
+++ b/epan/dissectors/packet-ppi.c
@@ -180,7 +180,7 @@ typedef enum {
MOHAMED_THAGA_PRIVATE = 30001,
PPI_GPS_INFO = 30002, /* 30002 - 30005 described in PPI-GEOLOCATION specifcation */
PPI_VECTOR_INFO = 30003, /* currently available in draft from. jellch@harris.com */
- PPI_HARRIS_TEST0 = 30004, /* 30004 is used for testing geolocation tag enhancements */
+ PPI_SENSOR_INFO = 30004,
PPI_ANTENNA_INFO = 30005,
CACE_PRIVATE = 0xCACE
/* All others RESERVED. Contact the WinPcap team for an assignment */
@@ -320,7 +320,7 @@ static gint ett_8023_extension_errors = -1;
static dissector_handle_t data_handle;
static dissector_handle_t ieee80211_ht_handle;
-static dissector_handle_t ppi_gps_handle, ppi_vector_handle, ppi_harris_test_handle, ppi_antenna_handle;
+static dissector_handle_t ppi_gps_handle, ppi_vector_handle, ppi_sensor_handle, ppi_antenna_handle;
static const true_false_string tfs_ppi_head_flag_alignment = { "32-bit aligned", "Not aligned" };
@@ -343,7 +343,7 @@ static const value_string vs_ppi_field_type[] = {
{MOHAMED_THAGA_PRIVATE, "Mohamed Thaga (private)"},
{PPI_GPS_INFO, "GPS Tagging"},
{PPI_VECTOR_INFO, "Vector Tagging"},
- {PPI_HARRIS_TEST0, "Harris geolocation-tag development"},
+ {PPI_SENSOR_INFO, "Sensor tagging"},
{PPI_ANTENNA_INFO, "Antenna Tagging"},
{CACE_PRIVATE, "CACE Technologies (private)"},
{0, NULL}
@@ -855,17 +855,17 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
call_dissector(ppi_vector_handle, next_tvb, pinfo, ppi_tree);
}
break;
- case PPI_HARRIS_TEST0:
- if (ppi_harris_test_handle == NULL)
+ case PPI_SENSOR_INFO:
+ if (ppi_sensor_handle == NULL)
{
proto_tree_add_text(ppi_tree, tvb, offset, data_len,
"%s (%u bytes)", val_to_str(data_type, (value_string *)&vs_ppi_field_type, "HARRIS: "), data_len);
}
else /* we found a suitable dissector */
{
/* skip over the ppi_fieldheader, and pass it off to the dedicated ANTENNA_ORIENTATION dissetor */
next_tvb = tvb_new_subset(tvb, offset + 4, data_len - 4 , -1);
- call_dissector(ppi_harris_test_handle, next_tvb, pinfo, ppi_tree);
+ call_dissector(ppi_sensor_handle, next_tvb, pinfo, ppi_tree);
}
break;
case PPI_ANTENNA_INFO:
@@ -1361,7 +1361,7 @@ proto_reg_handoff_ppi(void)
ieee80211_ht_handle = find_dissector("wlan_ht");
ppi_gps_handle = find_dissector("ppi_gps");
ppi_vector_handle = find_dissector("ppi_vector");
- ppi_harris_test_handle = find_dissector("ppi_harris_test");
+ ppi_sensor_handle = find_dissector("ppi_sensor");
ppi_antenna_handle = find_dissector("ppi_antenna");
dissector_add_uint("wtap_encap", WTAP_ENCAP_PPI, ppi_handle);
@@ -855,17 +855,17 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
else /* we found a suitable dissector */
{
- /* skip over the ppi_fieldheader, and pass it off to the dedicated ANTENNA_ORIENTATION dissetor */
+ /* skip over the ppi_fieldheader, and pass it off to the dedicated SENSOR dissetor */
next_tvb = tvb_new_subset(tvb, offset + 4, data_len - 4 , -1);